pub struct EffectContext { /* private fields */ }Expand description
What an effect’s action knows about the attempt it is running.
Implementations
Sourceimpl EffectContext
impl EffectContext
Sourcepub fn idempotency_key(&self) -> IdempotencyKey
pub fn idempotency_key(&self) -> IdempotencyKey
The key to forward to the remote system, e.g. as an HTTP
Idempotency-Key header. The same for every attempt of the effect.