Effect identity: record ids, logical keys and remote idempotency keys.
Structs
- Effect
Id - Durable identity of one effect record.
- Effect
Key - The unique identity of a logical effect:
(name, logical key). - Effect
Name - The type of an effect, e.g.
payment.charge. - Idempotency
Key - A key a remote system can use to deduplicate requests, such as an HTTP
Idempotency-Keyheader. - Logical
Key - The application’s identifier for one logical occurrence of an effect,
e.g. the order id for
payment.charge. - Worker
Id - Identifies a runtime instance that holds execution leases.
Enums
- Identity
Error - Why an
EffectNameorLogicalKeywas rejected.
Constants
- MAX_
KEY_ LEN - Maximum length, in bytes, of a
LogicalKey. - MAX_
NAME_ LEN - Maximum length, in bytes, of an
EffectName.