Secret

Struct Secret 

pub struct Secret<T>(/* private fields */);
A value that must never be stored or logged.

use agent_effects::redaction::Secret;

#[derive(serde::Serialize)]
struct Charge {
    account: String,
    card_token: Secret<String>,
}

let charge = Charge { account: "acct_1".into(), card_token: Secret::new("tok_live_x".into()) };
assert_eq!(
    serde_json::to_string(&charge).unwrap(),
    r#"{"account":"acct_1","card_token":"[REDACTED]"}"#
);
assert_eq!(format!("{:?}", charge.card_token), "[REDACTED]");
assert_eq!(charge.card_token.expose().map(String::as_str), Some("tok_live_x"));

Implementations

Source

impl<T> Secret<T>

pub const fn new(value: T) -> Self

Wraps value.

pub const fn expose(&self) -> Option<&T>

The value, or None if this Secret was read back from storage, where only "[REDACTED]" was kept.

pub fn into_inner(self) -> Option<T>

The value, consuming the wrapper; None as for Self::expose.

pub const fn is_redacted(&self) -> bool

Whether the value is gone because it was read back from storage.